﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Emgu.CV;
using Emgu.CV.Structure;
using Emgu.Util;

namespace EmguTestApplication
{
    class ImagePyramid
    {
        private Image<Gray,byte>[] imagePointers;

        private int pyramidHeight;


        public ImagePyramid(Image<Gray, byte> baseImage, int pHeight)
        {
            int width = baseImage.Width; int height = baseImage.Height;

            pyramidHeight = pHeight;

            imagePointers = (Image<Gray, byte>[])(new Image<Gray, byte>[pyramidHeight]);

            // Set base level (0)
            imagePointers[0] = baseImage;

            // Set rest of base levels
            for (int l = 1; l <= pyramidHeight - 1; l++)
            {
                width /= 2; height /= 2;

                Image<Gray, byte> gaussianPyramidFrame = new Image<Gray, byte>(width, height);

                CvInvoke.cvPyrDown(imagePointers[l - 1], gaussianPyramidFrame, Emgu.CV.CvEnum.FILTER_TYPE.CV_GAUSSIAN_5x5);

                imagePointers[l] = gaussianPyramidFrame.Clone();
            } 
        }

        public int PyramidHeight
        {
            get { return pyramidHeight; }
        }

        public Image<Gray,byte>[] PyramidLevel
        {
            get { return imagePointers;}
        }

    }
}
